You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@roller.apache.org by gm...@apache.org on 2014/08/09 22:29:17 UTC

svn commit: r1617014 - in /roller/trunk/app/src/main: java/org/apache/roller/weblogger/business/jpa/ java/org/apache/roller/weblogger/business/pings/ java/org/apache/roller/weblogger/ui/struts2/admin/ java/org/apache/roller/weblogger/ui/struts2/editor/...

Author: gmazza
Date: Sat Aug  9 20:29:17 2014
New Revision: 1617014

URL: http://svn.apache.org/r1617014
Log:
Consolidated PingTargetAdd and PingTargetEdit into the latter.

Removed:
    roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetAdd.java
Modified:
    roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/jpa/JPAPingTargetManagerImpl.java
    roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/pings/PingTargetManager.java
    roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetEdit.java
    roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/editor/FolderEdit.java
    roller/trunk/app/src/main/resources/ApplicationResources.properties
    roller/trunk/app/src/main/resources/ApplicationResources_de.properties
    roller/trunk/app/src/main/resources/ApplicationResources_es.properties
    roller/trunk/app/src/main/resources/ApplicationResources_fr.properties
    roller/trunk/app/src/main/resources/ApplicationResources_ja_JP.properties
    roller/trunk/app/src/main/resources/ApplicationResources_ko.properties
    roller/trunk/app/src/main/resources/ApplicationResources_ru.properties
    roller/trunk/app/src/main/resources/ApplicationResources_zh_CN.properties
    roller/trunk/app/src/main/resources/struts.xml

Modified: roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/jpa/JPAPingTargetManagerImpl.java
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/jpa/JPAPingTargetManagerImpl.java?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/jpa/JPAPingTargetManagerImpl.java (original)
+++ roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/jpa/JPAPingTargetManagerImpl.java Sat Aug  9 20:29:17 2014
@@ -81,37 +81,25 @@ public class JPAPingTargetManagerImpl im
         return (PingTarget)strategy.load(PingTarget.class, id);
     }
 
-    public boolean isNameUnique(PingTarget pingTarget) 
+    public boolean targetNameExists(String pingTargetName)
             throws WebloggerException {
-        String name = pingTarget.getName();
-        if (name == null || name.trim().length() == 0) {
-            return false;
-        }
-        
-        String id = pingTarget.getId();
-        
-        // Determine the set of "brother" targets
-        // among which this name should be unique.
-        List<PingTarget> brotherTargets;
-        brotherTargets = getCommonPingTargets();
 
-        // Within that set of targets, fail if there is a target 
+        // Within that set of targets, fail if there is a target
         // with the same name and that target doesn't
         // have the same id.
-        for (PingTarget brother : brotherTargets) {
-            if (brother.getName().equals(name) &&
-                    (id == null || !brother.getId().equals(id))) {
-                return false;
+        for (PingTarget pt : getCommonPingTargets()) {
+            if (pt.getName().equals(pingTargetName)) {
+                return true;
             }
         }
         // No conflict found
-        return true;
+        return false;
     }
 
     
-    public boolean isUrlWellFormed(PingTarget pingTarget) 
+    public boolean isUrlWellFormed(String url)
             throws WebloggerException {
-        String url = pingTarget.getPingUrl();
+
         if (url == null || url.trim().length() == 0) {
             return false;
         }
@@ -129,9 +117,8 @@ public class JPAPingTargetManagerImpl im
     }
 
     
-    public boolean isHostnameKnown(PingTarget pingTarget) 
+    public boolean isHostnameKnown(String url)
             throws WebloggerException {
-        String url = pingTarget.getPingUrl();
         if (url == null || url.trim().length() == 0) {
             return false;
         }

Modified: roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/pings/PingTargetManager.java
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/pings/PingTargetManager.java?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetEdit.java (original)
+++ roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetEdit.java Sat Aug  9 20:29:17 2014
@@ -34,12 +34,12 @@ public class PingTargetEdit extends UIAc
     
     private static Log log = LogFactory.getLog(PingTargetEdit.class);
 
-    // ping target we are working on, if any
-    private PingTarget pingTarget = null;
-
     // a bean for managing submitted data
     private PingTargetBean bean = new PingTargetBean();
 
+    // ping target we are working on, if any
+    private PingTarget pingTarget = null;
+
     public PingTargetEdit() {
         this.desiredMenu = "admin";
         this.pageTitle = "pingTarget.pingTarget";
@@ -52,28 +52,28 @@ public class PingTargetEdit extends UIAc
 
     public void myPrepare() {
         PingTargetManager pingTargetMgr = WebloggerFactory.getWeblogger().getPingTargetManager();
-        if(!StringUtils.isEmpty(getBean().getId())) {
+
+        if (!StringUtils.isEmpty(getBean().getId())) {
+            // edit case
             try {
                 pingTarget = pingTargetMgr.getPingTarget(getBean().getId());
             } catch (WebloggerException ex) {
                 log.error("Error looking up ping target - " + getBean().getId());
             }
-            if(pingTarget == null) {
+            if (pingTarget == null) {
                 addError("pingTarget.notFound", getBean().getId());
             }
         } else {
-            addError("pingTarget.unspecified");
+            // add case
+            pingTarget = new PingTarget();
+            pingTarget.setConditionCode(PingTarget.CONDITION_OK);
+            pingTarget.setAutoEnabled(false);
         }
     }
 
     public String execute() {
-        if(!hasActionErrors()) {
-            // load bean with data from ping target
+        if (!isAdd()) {
             getBean().copyFrom(pingTarget);
-        } else {
-            // if we already have an error then that means we couldn't load
-            // an existing ping target to work on, so return ERROR result
-            return ERROR;
         }
         return INPUT;
     }
@@ -82,60 +82,63 @@ public class PingTargetEdit extends UIAc
      * Save ping target.
      */
     public String save() {
-
-        if(hasActionErrors()) {
-            // if we already have an error then that means we couldn't load
-            // an existing ping target to work on, so return ERROR result
-            return INPUT;
-        }
-
-        // copy data from form into ping target
-        getBean().copyTo(pingTarget);
-
-        // Call private helper to validate ping target
-        // If there are errors, go back to the target edit page.
-        myValidate(pingTarget);
+        myValidate();
 
         if (!hasActionErrors()) {
             try {
-                // Appears to be ok.  Save it and flush.
+                // copy data from form into ping target
+                getBean().copyTo(pingTarget);
                 PingTargetManager pingTargetMgr = WebloggerFactory.getWeblogger().getPingTargetManager();
                 pingTargetMgr.savePingTarget(pingTarget);
                 WebloggerFactory.getWeblogger().flush();
 
-                addMessage("pingTarget.saved");
+                addMessage(isAdd() ? "pingTarget.created" : "pingTarget.updated",
+                        pingTarget.getName());
+
+                return SUCCESS;
             } catch (WebloggerException ex) {
-                log.error("Error saving ping target", ex);
-                addError("pingTarget.saved.error");
+                log.error("Error adding/editing ping target", ex);
+                addError("generic.error.check.logs");
             }
         }
 
         return INPUT;
     }
 
-
     /**
      * Private helper to validate a ping target.
      */
-    protected void myValidate(PingTarget pingTarget) {
-
+    protected void myValidate() {
         try {
             PingTargetManager pingTargetMgr = WebloggerFactory.getWeblogger().getPingTargetManager();
-            if (!pingTargetMgr.isNameUnique(pingTarget)) {
-                addError("pingTarget.nameNotUnique");
+            if (StringUtils.isEmpty(bean.getName())) {
+                addError("pingTarget.nameMissing");
+            } else {
+                if (isAdd() || !pingTarget.getName().equals(bean.getName())) {
+                    if (pingTargetMgr.targetNameExists(bean.getName())) {
+                        addError("pingTarget.nameNotUnique");
+                    }
+                }
             }
-
-            if (!pingTargetMgr.isUrlWellFormed(pingTarget)) {
-                addError("pingTarget.malformedUrl");
-            } else if (!pingTargetMgr.isHostnameKnown(pingTarget)) {
-                addError("pingTarget.unknownHost");
+            if (StringUtils.isEmpty(bean.getPingUrl())) {
+                addError("pingTarget.pingUrlMissing");
+            } else {
+                if (!pingTargetMgr.isUrlWellFormed(bean.getPingUrl())) {
+                    addError("pingTarget.malformedUrl");
+                } else if (!pingTargetMgr.isHostnameKnown(bean.getPingUrl())) {
+                    addError("pingTarget.unknownHost");
+                }
             }
         } catch (WebloggerException ex) {
             log.error("Error validating ping target", ex);
-            addError("pingTarget.saved.error");
+            addError("generic.error.check.logs");
         }
     }
 
+    private boolean isAdd() {
+        return actionName.equals("commonPingTargetAdd");
+    }
+
     public PingTargetBean getBean() {
         return bean;
     }
@@ -143,6 +146,4 @@ public class PingTargetEdit extends UIAc
     public void setBean(PingTargetBean bean) {
         this.bean = bean;
     }
-
-
 }

Modified: roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/editor/FolderEdit.java
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/editor/FolderEdit.java?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/editor/FolderEdit.java (original)
+++ roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/editor/FolderEdit.java Sat Aug  9 20:29:17 2014
@@ -36,15 +36,15 @@ import org.apache.struts2.interceptor.va
 public class FolderEdit extends UIAction {
     
     private static Log log = LogFactory.getLog(FolderEdit.class);
-    
+
+    // bean for managing form data
+    private FolderBean bean = new FolderBean();
+
     // the id of the folder we are working with
     private String folderId = null;
-    
+
     // the folder we are adding or editing
     private WeblogBookmarkFolder folder = null;
-    
-    // bean for managing form data
-    private FolderBean bean = new FolderBean();
 
     public FolderEdit() {
         this.desiredMenu = "editor";

Modified: roller/trunk/app/src/main/resources/ApplicationResources.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources.properties Sat Aug  9 20:29:17 2014
@@ -1089,11 +1089,13 @@ pingTarget.disabled=OFF
 pingTarget.auto=Automatic
 pingTarget.manual=Manual
 pingTarget.sendPingNow=Send Ping Now
-pingTarget.saved=Ping target saved.
-pingTarget.saved.error=Error adding ping target.
-
-pingTarget.nameNotUnique=The name of this target conflicts with another one in \
-the same set of targets.
+pingTarget.updated=Ping target "{0}" updated
+pingTarget.created=Ping target "{0}" created
+pingTarget.saved.error=Error updating ping target.
+
+pingTarget.nameNotUnique=Target name already exists, please choose another.
+pingTarget.nameMissing=Name is required
+pingTarget.pingUrlMissing=Ping URL is required
 pingTarget.malformedUrl=The URL is not properly formed.
 pingTarget.unknownHost=The hostname in this URL doesn''t seem to exist.
 pingTarget.unspecified=No ping target id was specified in the request

Modified: roller/trunk/app/src/main/resources/ApplicationResources_de.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_de.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_de.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_de.properties Sat Aug  9 20:29:17 2014
@@ -576,7 +576,7 @@ pingTarget.nameNotUnique=Der Name dieses
 pingTarget.pingTarget=Ping Ziel
 pingTarget.pingUrl=Ping URL
 pingTarget.remove=L\u00F6schen
-pingTarget.saved=Ping-Ziel gespeichert
+pingTarget.updated=Ping-Ziel "{0}" gespeichert
 pingTarget.sendPingNow=Sende jetzt ein Ping
 pingTarget.unknownHost=Der Hostname in der URL scheint nicht zu existieren.
 pings.commonPingTargets=Allgemeine Ping Ziele

Modified: roller/trunk/app/src/main/resources/ApplicationResources_es.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_es.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_es.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_es.properties Sat Aug  9 20:29:17 2014
@@ -335,7 +335,7 @@ pingTarget.disabled=DESACTIVADO
 pingTarget.auto=Autom\u00E1tico
 pingTarget.manual=Manual
 pingTarget.sendPingNow=Enviar ping ahora
-pingTarget.saved=Objetivo ping guardado.
+pingTarget.updated=Objetivo ping "{0}" guardado.
 pingTarget.nameNotUnique=El nombre de este objetivo est\u00E1 en conflicto con otro en el mismo conjunto de objetivos.
 pingTarget.malformedUrl=La URL no est\u00E1 formada correctamente.
 pingTarget.unknownHost=El nombre de host de esta URL no parece existir.

Modified: roller/trunk/app/src/main/resources/ApplicationResources_fr.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_fr.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_fr.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_fr.properties Sat Aug  9 20:29:17 2014
@@ -694,7 +694,7 @@ pingTarget.disabled=Inactif
 pingTarget.auto=Automatique
 pingTarget.manual=Manuel
 pingTarget.sendPingNow=Notifier
-pingTarget.saved=Adresse de notification enregistrée.
+pingTarget.updated=Adresse de notification "{0}" enregistrée.
 
 pingTarget.nameNotUnique=Le nom utilisé existe déjà ou fait partie d'un nom existant.
 pingTarget.malformedUrl=L'URL utilisée est incorrecte.

Modified: roller/trunk/app/src/main/resources/ApplicationResources_ja_JP.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_ja_JP.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_ja_JP.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_ja_JP.properties Sat Aug  9 20:29:17 2014
@@ -560,7 +560,6 @@ pingTarget.disabled=\u624B\u52D5
 pingTarget.auto=\u81EA\u52D5
 pingTarget.manual=\u624B\u52D5
 pingTarget.sendPingNow=\u4ECA\u3059\u3050Ping\u3092\u6253\u3064
-pingTarget.saved=Ping\u30BF\u30FC\u30B2\u30C3\u30C8\u304C\u4FDD\u5B58\u3055\u308C\u307E\u3057\u305F
 
 pingTarget.nameNotUnique=\u540C\u3058\u540D\u524D\u306E\u30B5\u30A4\u30C8\u540D\u304C\u8A2D\u5B9A\u3055\u308C\u3066\u3044\u307E\u3059\u3002\u4ED6\u306E\u540D\u524D\u306B\u3057\u3066\u304F\u3060\u3055\u3044\u3002
 pingTarget.unknownHost=\u3053\u306EURL\u306E\u30DB\u30B9\u30C8\u304C\u898B\u4ED8\u304B\u308A\u307E\u305B\u3093

Modified: roller/trunk/app/src/main/resources/ApplicationResources_ko.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_ko.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_ko.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_ko.properties Sat Aug  9 20:29:17 2014
@@ -759,7 +759,6 @@ pingTarget.disabled=\ube44\ud65c\uc131
 pingTarget.auto=\uc790\ub3d9
 pingTarget.manual=\uc218\ub3d9
 pingTarget.sendPingNow=\uc5f0\uacb0\ud655\uc778 \uc9c0\uae08 \uc804\uc1a1
-pingTarget.saved=\uc5f0\uacb0\ud655\uc778 \ub300\uc0c1\uc774 \uc800\uc7a5\ub418\uc5c8\uc2b5\ub2c8\ub2e4.
 
 pingTarget.nameNotUnique=\uc774 \uc5f0\uacb0\ud655\uc778 \ub300\uc0c1\uc758 \uc774\ub984\uc774 \ub2e4\ub978 \ub300\uc0c1\uc758 \uc774\ub984\uacfc \ucda9\ub3cc\ud569\ub2c8\ub2e4.
 pingTarget.malformedUrl=URL\uc774 \uc801\uc808\ud558\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.

Modified: roller/trunk/app/src/main/resources/ApplicationResources_ru.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_ru.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_ru.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_ru.properties Sat Aug  9 20:29:17 2014
@@ -459,7 +459,6 @@ pingTarget.disabled=OFF
 pingTarget.auto=\u0410\u0432\u0442\u043e\u043c\u0430\u0442\u0438\u0447\u0435\u0441\u043a\u0438
 pingTarget.manual=\u0412\u0440\u0443\u0447\u043d\u0443\u044e
 pingTarget.sendPingNow=\u041f\u043e\u0441\u043b\u0430\u0442\u044c \u043f\u0438\u043d\u0433
-pingTarget.saved=\u0410\u0434\u0440\u0435\u0441 \u043f\u0438\u043d\u0433\u0430 \u0441\u043e\u0445\u0440\u0430\u043d\u0435\u043d
 
 pingTarget.nameNotUnique=\u0418\u043c\u044f \u044d\u0442\u043e\u0439 \u0446\u0435\u043b\u0438 \u043a\u043e\u043d\u0444\u043b\u0438\u043a\u0442\u0443\u0435\u0442 \u0441 \u0434\u0440\u0443\u0433\u0438\u043c \u0432 \u0442\u043e\u043c \u0436\u0435 \u043d\u0430\u0431\u043e\u0440\u0435 \u0446\u0435\u043b\u0435\u0439.
 pingTarget.malformedUrl=URL \u043d\u0435\u043f\u0440\u0430\u0432\u0438\u043b\u044c\u043d\u043e \u0441\u0444\u043e\u0440\u043c\u0438\u0440\u043e\u0432\u0430\u043d.

Modified: roller/trunk/app/src/main/resources/ApplicationResources_zh_CN.properties
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/ApplicationResources_zh_CN.properties?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/ApplicationResources_zh_CN.properties (original)
+++ roller/trunk/app/src/main/resources/ApplicationResources_zh_CN.properties Sat Aug  9 20:29:17 2014
@@ -338,7 +338,6 @@ pingTarget.nameNotUnique=\u8fd9\u4e2aPin
 pingTarget.pingTarget=Ping\u76ee\u6807
 pingTarget.pingUrl=Ping URL\u5730\u5740
 pingTarget.remove=\u5220\u9664
-pingTarget.saved=Ping\u76ee\u6807\u5df2\u4fdd\u5b58\u3002
 pingTarget.sendPingNow=\u53d1\u9001Ping\u2026\u2026
 pingTarget.unknownHost=\u8be5URL\u4e3b\u673a\u5730\u5740\u4e0d\u5b58\u5728\u3002
 pings.commonPingTargets=\u666e\u901aPing\u76ee\u6807

Modified: roller/trunk/app/src/main/resources/struts.xml
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/resources/struts.xml?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================
--- roller/trunk/app/src/main/resources/struts.xml (original)
+++ roller/trunk/app/src/main/resources/struts.xml Sat Aug  9 20:29:17 2014
@@ -194,7 +194,7 @@
         </action>
         
         <action name="commonPingTargetAdd!*" method="{1}"
-                class="org.apache.roller.weblogger.ui.struts2.admin.PingTargetAdd">
+                class="org.apache.roller.weblogger.ui.struts2.admin.PingTargetEdit">
             <param name="actionName">commonPingTargetAdd</param>
             <result name="input" type="tiles">.PingTargetEdit</result>
             <result name="success" type="chain">commonPingTargets</result>
@@ -204,6 +204,7 @@
                 class="org.apache.roller.weblogger.ui.struts2.admin.PingTargetEdit">
             <param name="actionName">commonPingTargetEdit</param>
             <result name="input" type="tiles">.PingTargetEdit</result>
+            <result name="success" type="chain">commonPingTargets</result>
             <result name="error" type="chain">commonPingTargets</result>
         </action>
--- roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/pings/PingTargetManager.java (original)
+++ roller/trunk/app/src/main/java/org/apache/roller/weblogger/business/pings/PingTargetManager.java Sat Aug  9 20:29:17 2014
@@ -67,40 +67,36 @@ public interface PingTargetManager {
     List<PingTarget> getCommonPingTargets() throws WebloggerException;
 
     /**
-     * Check if the ping target has a name that is unique in the appropriate set.  If the ping target has no website id
-     * (is common), then this checks if the name is unique amongst common targets, and if custom then unique amongst
-     * custom targets. If the target has a non-null id, then it is allowed to have the same name as tha existing stored
-     * target with the same id.
+     * Check if the ping target name already exists in Roller.
      *
-     * @param pingTarget
-     * @return true if the name is unique in the appropriate set (custom or common) ping targets.
+     * @param pingTargetName ping target name to check
+     * @return true if there is already a ping target with this name, false otherwise
      * @throws WebloggerException
      */
-    boolean isNameUnique(PingTarget pingTarget) throws WebloggerException;
-    
+    boolean targetNameExists(String pingTargetName) throws WebloggerException;
     
     /**
-     * Check if the url of the ping target is well-formed.  For this test, it must parse as a <code>java.net.URL</code>,
+     * Check if the url of a ping target is well-formed.  For this test, it must parse as a <code>java.net.URL</code>,
      * with protocol <code>http</code> and a non-empty <code>host</code> portion.
      *
      * @param pingTarget
      * @return true if the <code>pingUrl</code> property of the ping target is a well-formed url.
      * @throws WebloggerException
      */
-    boolean isUrlWellFormed(PingTarget pingTarget) throws WebloggerException;
+    boolean isUrlWellFormed(String pingTargetUrl) throws WebloggerException;
     
     
     /**
-     * Check if the host portion of the url of the ping target is known, meaning it is either a well-formed IP address
+     * Check if the host portion of the url of a ping target is known, meaning it is either a well-formed IP address
      * or a hostname that resolves from the server.  The ping target url must parse as a <code>java.net.URL</code> in
      * order for the hostname to be extracted for this test.  This will return false if that parsing fails.
      *
      * @param pingTarget
      * @return true if the <code>pingUrl</code> (is well-formed and) the <code>host</code> portion of the url of the
      *         ping target is a valid IP address or a hostname that can be resolved on the server.
      * @throws WebloggerException
      */
-    boolean isHostnameKnown(PingTarget pingTarget) throws WebloggerException;
+    boolean isHostnameKnown(String pingTargetUrl) throws WebloggerException;
     
     
     /**
@@ -67,40 +67,36 @@ public interface PingTargetManager {
      * with protocol <code>http</code> and a non-empty <code>host</code> portion.
      *
-     * @param pingTarget
-     * @return true if the <code>pingUrl</code> property of the ping target is a well-formed url.
+     * @param pingTargetUrl url to check.
+     * @return true if the <code>pingTargetUrl</code> property of the ping target is a well-formed url.
      * @throws WebloggerException
      */
@@ -67,40 +67,36 @@ public interface PingTargetManager {
      * order for the hostname to be extracted for this test.  This will return false if that parsing fails.
      *
-     * @param pingTarget
-     * @return true if the <code>pingUrl</code> (is well-formed and) the <code>host</code> portion of the url of the
+     * @param pingTargetUrl url to check.
+     * @return true if the <code>pingTargetUrl</code> (is well-formed and) the <code>host</code> portion of the url of the
      *         ping target is a valid IP address or a hostname that can be resolved on the server.
      * @throws WebloggerException

Modified: roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetEdit.java
URL: http://svn.apache.org/viewvc/roller/trunk/app/src/main/java/org/apache/roller/weblogger/ui/struts2/admin/PingTargetEdit.java?rev=1617014&r1=1617013&r2=1617014&view=diff
==============================================================================